PCAschott: Testing for Subsphericity using the Schott's test
Description
The test tests the equality of the last eigenvalues assuming normal distributed data using the regular covariance matrix.
Usage
PCAschott(X, k)
Value
A list of class ictest inheriting from class htest containing:
statistic
the value of the test statistic.
p.value
the p-value of the test.
parameter
the degrees of freedom of the test.
method
character string which test was performed.
data.name
character string giving the name of the data.
alternative
character string specifying the alternative hypothesis.
k
the number or larger eigenvalues used in the testing problem.
W
the transformation matrix to the principal components.
S
data matrix with the centered principal components.
D
the underlying eigenvalues.
MU
the mean vector of the data which was substracted before calculating the principal components.
SCATTER
the computed covariance matrix matrix.
Arguments
X
a numeric data matrix with p>1 columns.
k
the number of eigenvalues larger than the equal ones. Can be between 0 and p-2.
Author
Klaus Nordhausen
Details
The functions assumes multivariate normal data and tests if the last \(p-k\) eigenvalues of PCA are equal.
References
Schott, J.R. (2006), A High-Dimensional Test for the Equality of the Smallest Eigenvalues of a Covariance Matrix, Journal of Multivariate Analysis, 97, 827--843. <doi:10.1016/j.jmva.2005.05.003>