Learn R Programming

ICtest (version 0.3-7)

components: Extract Components from 'ictest' and 'ladle' Objects

Description

Methods for the components generic from the ICS package to extract components from objects of class ictest and ladle. The user can choose whether all components are extracted or only those relevant under the null hypothesis.

Usage

# S3 method for ictest
components(x, which = "all", ...)
# S3 method for ladle
components(x, which = "all", ...)

Value

a matrix with the components.

Arguments

x

an object which has a components method, like for example an ictest object.

which

for an object of class ictest. If "all", then all components S in the ictest object are extracted. If "k", then only the first k components are extracted, where the value of k is taken from the ictest object. This is only meaningful if k was at least 1.

...

arguments passed on to other methods.

Author

Klaus Nordhausen

Examples

Run this code
n <- 200
X <- cbind(rnorm(n, sd = 2), rnorm(n, sd = 1.5), rnorm(n), rnorm(n), rnorm(n))

TestCov <- PCAasymp(X, k = 2)
head(components(TestCov))
head(components(TestCov, which = "k"))

Run the code above in your browser using DataLab