powered by
Basic printing of an object of class kSearch. Prints the estimated dimension k along with all tested values and corresponding p-values.
kSearch
k
# S3 method for kSearch print(x, digits = getOption("digits"), ...)
An object of class kSearch.
Number of significant digits to use when printing p-values. Defaults to getOption("digits").
getOption("digits")
Further arguments.
Katariina Perkonoja
summary.kSearch, kSearch
summary.kSearch
n <- 500 S <- cbind(rnorm(n, sd = 2), rnorm(n, sd = 1.5), rnorm(n), rnorm(n)) A <- rorth(4) X <- S %*% t(A) result <- kSearch(X, method = PCAasymp) result
Run the code above in your browser using DataLab