| components | R Documentation |
Methods for the components generic from the ICS package
to extract components from objects of class ictest and ladle.
The user can choose whether all components are extracted or only those
relevant under the null hypothesis.
## S3 method for class 'ictest'
components(x, which = "all", ...)
## S3 method for class 'ladle'
components(x, which = "all", ...)
x |
an object which has a components method, like for example an ictest object. |
which |
for an object of class ictest. If |
... |
arguments passed on to other methods. |
a matrix with the components.
Klaus Nordhausen
n <- 200
X <- cbind(rnorm(n, sd = 2), rnorm(n, sd = 1.5), rnorm(n), rnorm(n), rnorm(n))
TestCov <- PCAasymp(X, k = 2)
head(components(TestCov))
head(components(TestCov, which = "k"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.